summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:03 -0600
commit9c9412b30c54468adc9e506cc76c5d113fbf5056 (patch)
tree68a0c0d5bc770fc58596b8c5624cdf33d8625027 /kopete/libkopete/ui
parent2e53bd0b77676f879fad7baeecea5879bf496a7d (diff)
downloadtdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.tar.gz
tdenetwork-9c9412b30c54468adc9e506cc76c5d113fbf5056.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kopete/libkopete/ui')
-rw-r--r--kopete/libkopete/ui/accountselector.cpp8
-rw-r--r--kopete/libkopete/ui/accountselector.h6
-rw-r--r--kopete/libkopete/ui/addressbookselectorwidget.cpp2
-rw-r--r--kopete/libkopete/ui/addressbookselectorwidget_base.ui4
-rw-r--r--kopete/libkopete/ui/addresseeitem.cpp2
-rw-r--r--kopete/libkopete/ui/addresseeitem.h2
-rw-r--r--kopete/libkopete/ui/kopetecontactaction.cpp6
-rw-r--r--kopete/libkopete/ui/kopetecontactaction.h6
-rw-r--r--kopete/libkopete/ui/kopetelistview.cpp10
-rw-r--r--kopete/libkopete/ui/kopetelistview.h4
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.cpp14
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.h2
-rw-r--r--kopete/libkopete/ui/kopetelistviewsearchline.cpp8
-rw-r--r--kopete/libkopete/ui/kopetelistviewsearchline.h4
-rw-r--r--kopete/libkopete/ui/kopetestdaction.cpp52
-rw-r--r--kopete/libkopete/ui/kopetestdaction.h28
-rw-r--r--kopete/libkopete/ui/kopeteview.h4
17 files changed, 81 insertions, 81 deletions
diff --git a/kopete/libkopete/ui/accountselector.cpp b/kopete/libkopete/ui/accountselector.cpp
index 345e9ab4..f6cd3855 100644
--- a/kopete/libkopete/ui/accountselector.cpp
+++ b/kopete/libkopete/ui/accountselector.cpp
@@ -26,14 +26,14 @@
#include <kdebug.h>
#include <klistview.h>
-class AccountListViewItem : public KListViewItem
+class AccountListViewItem : public TDEListViewItem
{
private:
Kopete::Account *mAccount;
public:
AccountListViewItem(TQListView *parent, Kopete::Account *acc)
- : KListViewItem(parent)
+ : TDEListViewItem(parent)
{
if (acc==0)
return;
@@ -57,7 +57,7 @@ class AccountListViewItem : public KListViewItem
class AccountSelectorPrivate
{
public:
- KListView *lv;
+ TDEListView *lv;
Kopete::Protocol *proto;
};
@@ -93,7 +93,7 @@ void AccountSelector::initUI()
{
kdDebug(14010) << k_funcinfo << endl;
(new TQVBoxLayout(this))->setAutoAdd(true);
- d->lv = new KListView(this);
+ d->lv = new TDEListView(this);
d->lv->setFullWidth(true);
d->lv->addColumn(TQString::fromLatin1(""));
d->lv->header()->hide();
diff --git a/kopete/libkopete/ui/accountselector.h b/kopete/libkopete/ui/accountselector.h
index f675603f..6beb35c9 100644
--- a/kopete/libkopete/ui/accountselector.h
+++ b/kopete/libkopete/ui/accountselector.h
@@ -25,7 +25,7 @@
class AccountSelectorPrivate;
class TQListViewItem;
/**
- * \brief widget to select an account, based on KListView
+ * \brief widget to select an account, based on TDEListView
* @author Stefan Gehn <metz AT gehn.net>
*/
class KOPETE_EXPORT AccountSelector : public TQWidget
@@ -38,7 +38,7 @@ Q_OBJECT
* Constructor.
*
* The parameters @p parent and @p name are handled by
- * KListView.
+ * TDEListView.
*/
AccountSelector(TQWidget *parent=0, const char *name=0);
@@ -46,7 +46,7 @@ Q_OBJECT
* Constructor for a list of accounts for one protocol only
*
* The parameters @p parent and @p name are handled by
- * KListView. @p proto defines the protocol whose accounts are
+ * TDEListView. @p proto defines the protocol whose accounts are
* shown in the list
*/
AccountSelector(Kopete::Protocol *proto, TQWidget *parent=0, const char *name=0);
diff --git a/kopete/libkopete/ui/addressbookselectorwidget.cpp b/kopete/libkopete/ui/addressbookselectorwidget.cpp
index 5a75bbf9..16009ee5 100644
--- a/kopete/libkopete/ui/addressbookselectorwidget.cpp
+++ b/kopete/libkopete/ui/addressbookselectorwidget.cpp
@@ -72,7 +72,7 @@ AddressBookSelectorWidget::AddressBookSelectorWidget( TQWidget *parent, const ch
connect( m_addressBook, TQT_SIGNAL( addressBookChanged( AddressBook * ) ), this, TQT_SLOT( slotLoadAddressees() ) );
- //We should add a clear KAction here. But we can't really do that with a designer file :\ this sucks
+ //We should add a clear TDEAction here. But we can't really do that with a designer file :\ this sucks
addresseeListView->setColumnText(2, SmallIconSet(TQString::fromLatin1("email")), i18n("Email"));
diff --git a/kopete/libkopete/ui/addressbookselectorwidget_base.ui b/kopete/libkopete/ui/addressbookselectorwidget_base.ui
index 423b2047..ee4c2016 100644
--- a/kopete/libkopete/ui/addressbookselectorwidget_base.ui
+++ b/kopete/libkopete/ui/addressbookselectorwidget_base.ui
@@ -71,7 +71,7 @@
</sizepolicy>
</property>
</widget>
- <widget class="KListView" row="2" column="0" rowspan="1" colspan="2">
+ <widget class="TDEListView" row="2" column="0" rowspan="1" colspan="2">
<column>
<property name="text">
<string>Photo</string>
@@ -153,7 +153,7 @@
<cstring>kListViewSearchLine</cstring>
</property>
</widget>
- <widget class="KListViewSearchLine">
+ <widget class="TDEListViewSearchLine">
<property name="name">
<cstring>kListViewSearchLine</cstring>
</property>
diff --git a/kopete/libkopete/ui/addresseeitem.cpp b/kopete/libkopete/ui/addresseeitem.cpp
index 9fa9f023..724f277c 100644
--- a/kopete/libkopete/ui/addresseeitem.cpp
+++ b/kopete/libkopete/ui/addresseeitem.cpp
@@ -28,7 +28,7 @@
#include "addresseeitem.h"
AddresseeItem::AddresseeItem( TQListView *parent, const KABC::Addressee &addressee) :
- KListViewItem( parent ),
+ TDEListViewItem( parent ),
mAddressee( addressee )
{
//We can't save showphoto because we don't have a d pointer
diff --git a/kopete/libkopete/ui/addresseeitem.h b/kopete/libkopete/ui/addresseeitem.h
index 36d1d284..29546ebc 100644
--- a/kopete/libkopete/ui/addresseeitem.h
+++ b/kopete/libkopete/ui/addresseeitem.h
@@ -32,7 +32,7 @@
/**
@short Special ListViewItem
*/
-class AddresseeItem : public KListViewItem
+class AddresseeItem : public TDEListViewItem
{
public:
diff --git a/kopete/libkopete/ui/kopetecontactaction.cpp b/kopete/libkopete/ui/kopetecontactaction.cpp
index cc6754d2..b2e8dba0 100644
--- a/kopete/libkopete/ui/kopetecontactaction.cpp
+++ b/kopete/libkopete/ui/kopetecontactaction.cpp
@@ -1,5 +1,5 @@
/*
- kopetecontactaction.cpp - KAction for selecting a Kopete::Contact
+ kopetecontactaction.cpp - TDEAction for selecting a Kopete::Contact
Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
@@ -22,8 +22,8 @@
#include "kopeteonlinestatus.h"
KopeteContactAction::KopeteContactAction( Kopete::Contact *contact, const TQObject *receiver,
- const char *slot, KAction *parent )
-: KAction( contact->metaContact()->displayName(), TQIconSet( contact->onlineStatus().iconFor( contact ) ), KShortcut(),
+ const char *slot, TDEAction *parent )
+: TDEAction( contact->metaContact()->displayName(), TQIconSet( contact->onlineStatus().iconFor( contact ) ), TDEShortcut(),
parent, contact->contactId().latin1() )
{
m_contact = contact;
diff --git a/kopete/libkopete/ui/kopetecontactaction.h b/kopete/libkopete/ui/kopetecontactaction.h
index 15143697..3b370916 100644
--- a/kopete/libkopete/ui/kopetecontactaction.h
+++ b/kopete/libkopete/ui/kopetecontactaction.h
@@ -1,5 +1,5 @@
/*
- kopetecontactaction.cpp - KAction for selecting a Kopete::Contact
+ kopetecontactaction.cpp - TDEAction for selecting a Kopete::Contact
Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
@@ -29,7 +29,7 @@ class Contact;
/**
* @author Martijn Klingens <klingens@kde.org>
*/
-class KOPETE_EXPORT KopeteContactAction : public KAction
+class KOPETE_EXPORT KopeteContactAction : public TDEAction
{
Q_OBJECT
@@ -38,7 +38,7 @@ public:
/**
* Create a new KopeteContactAction
*/
- KopeteContactAction( Kopete::Contact *contact, const TQObject* receiver, const char* slot, KAction* parent );
+ KopeteContactAction( Kopete::Contact *contact, const TQObject* receiver, const char* slot, TDEAction* parent );
~KopeteContactAction();
Kopete::Contact * contact() const;
diff --git a/kopete/libkopete/ui/kopetelistview.cpp b/kopete/libkopete/ui/kopetelistview.cpp
index b0f7e787..44b2a8d9 100644
--- a/kopete/libkopete/ui/kopetelistview.cpp
+++ b/kopete/libkopete/ui/kopetelistview.cpp
@@ -103,7 +103,7 @@ struct ListView::Private
};
ListView::ListView( TQWidget *parent, const char *name )
- : KListView( parent, name ), d( new Private )
+ : TDEListView( parent, name ), d( new Private )
{
connect( &d->sortTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotSort() ) );
@@ -111,8 +111,8 @@ ListView::ListView( TQWidget *parent, const char *name )
setShowToolTips( false );
d->toolTip.reset( new ToolTip( viewport(), this ) );
- connect( this, TQT_SIGNAL( contextMenu( KListView *, TQListViewItem *, const TQPoint & ) ),
- TQT_SLOT( slotContextMenu( KListView *, TQListViewItem *, const TQPoint & ) ) );
+ connect( this, TQT_SIGNAL( contextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ),
+ TQT_SLOT( slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ) );
connect( this, TQT_SIGNAL( doubleClicked( TQListViewItem * ) ),
TQT_SLOT( slotDoubleClicked( TQListViewItem * ) ) );
@@ -147,7 +147,7 @@ void ListView::slotDoubleClicked( TQListViewItem *item )
setOpen( item, !isOpen( item ) );
}
-void ListView::slotContextMenu( KListView * /*listview*/,
+void ListView::slotContextMenu( TDEListView * /*listview*/,
TQListViewItem *item, const TQPoint &/*point*/ )
{
if ( item && !item->isSelected() )
@@ -197,7 +197,7 @@ void ListView::keyPressEvent( TQKeyEvent *e )
emitExecute( currentItem(), p, 0 );
}
else
- KListView::keyPressEvent(e);
+ TDEListView::keyPressEvent(e);
}
void ListView::delayedSort()
diff --git a/kopete/libkopete/ui/kopetelistview.h b/kopete/libkopete/ui/kopetelistview.h
index 79a96dbb..98ae4b19 100644
--- a/kopete/libkopete/ui/kopetelistview.h
+++ b/kopete/libkopete/ui/kopetelistview.h
@@ -29,7 +29,7 @@ namespace ListView {
* @author Engin AYDOGAN <engin@bzzzt.biz>
* @author Richard Smith <kde@metafoo.co.uk>
*/
-class ListView : public KListView
+class ListView : public TDEListView
{
Q_OBJECT
@@ -59,7 +59,7 @@ public slots:
protected:
virtual void keyPressEvent( TQKeyEvent *e );
private slots:
- void slotContextMenu(KListView*,TQListViewItem *item, const TQPoint &point );
+ void slotContextMenu(TDEListView*,TQListViewItem *item, const TQPoint &point );
void slotDoubleClicked( TQListViewItem *item );
private:
struct Private;
diff --git a/kopete/libkopete/ui/kopetelistviewitem.cpp b/kopete/libkopete/ui/kopetelistviewitem.cpp
index 03616908..6a0cfae4 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.cpp
+++ b/kopete/libkopete/ui/kopetelistviewitem.cpp
@@ -1280,13 +1280,13 @@ bool Item::Private::fadeVisibility = true;
bool Item::Private::foldVisibility = true;
Item::Item( TQListViewItem *parent, TQObject *owner, const char *name )
- : TQObject( owner, name ), KListViewItem( parent ), d( new Private(this) )
+ : TQObject( owner, name ), TDEListViewItem( parent ), d( new Private(this) )
{
initLVI();
}
Item::Item( TQListView *parent, TQObject *owner, const char *name )
- : TQObject( owner, name ), KListViewItem( parent ), d( new Private(this) )
+ : TQObject( owner, name ), TDEListViewItem( parent ), d( new Private(this) )
{
initLVI();
}
@@ -1469,7 +1469,7 @@ void Item::relayout()
void Item::setup()
{
- KListViewItem::setup();
+ TDEListViewItem::setup();
slotLayoutItems();
}
@@ -1484,7 +1484,7 @@ void Item::setHeight( int )
int vis = TQMIN( d->visibilityLevel, Private::visibilityFoldSteps );
minHeight = (minHeight * vis) / Private::visibilityFoldSteps;
}
- KListViewItem::setHeight( minHeight );
+ TDEListViewItem::setHeight( minHeight );
}
int Item::width( const TQFontMetrics &, const TQListView *lv, int c ) const
@@ -1498,15 +1498,15 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
{
TQPixmap back( width, height() );
TQPainter paint( &back );
- //KListViewItem::paintCell( &paint, cg, column, width, align );
+ //TDEListViewItem::paintCell( &paint, cg, column, width, align );
// PASTED FROM KLISTVIEWITEM:
// set the alternate cell background colour if necessary
TQColorGroup _cg = cg;
if (isAlternate())
if (listView()->viewport()->backgroundMode()==TQt::FixedColor)
- _cg.setColor(TQColorGroup::Background, static_cast< KListView* >(listView())->alternateBackground());
+ _cg.setColor(TQColorGroup::Background, static_cast< TDEListView* >(listView())->alternateBackground());
else
- _cg.setColor(TQColorGroup::Base, static_cast< KListView* >(listView())->alternateBackground());
+ _cg.setColor(TQColorGroup::Base, static_cast< TDEListView* >(listView())->alternateBackground());
// PASTED FROM TQLISTVIEWITEM
{
TQPainter *p = &paint;
diff --git a/kopete/libkopete/ui/kopetelistviewitem.h b/kopete/libkopete/ui/kopetelistviewitem.h
index 8285047a..871f1a6d 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.h
+++ b/kopete/libkopete/ui/kopetelistviewitem.h
@@ -451,7 +451,7 @@ public:
*
* @author Richard Smith <kde@metafoo.co.uk>
*/
-class Item : public TQObject, public KListViewItem, public ComponentBase
+class Item : public TQObject, public TDEListViewItem, public ComponentBase
{
Q_OBJECT
diff --git a/kopete/libkopete/ui/kopetelistviewsearchline.cpp b/kopete/libkopete/ui/kopetelistviewsearchline.cpp
index edb63ffc..24acfb08 100644
--- a/kopete/libkopete/ui/kopetelistviewsearchline.cpp
+++ b/kopete/libkopete/ui/kopetelistviewsearchline.cpp
@@ -25,12 +25,12 @@ namespace UI {
namespace ListView {
SearchLine::SearchLine( TQWidget *parent, ListView *listView, const char *name )
- : KListViewSearchLine( parent, listView, name )
+ : TDEListViewSearchLine( parent, listView, name )
{
}
SearchLine::SearchLine(TQWidget *parent, const char *name)
- : KListViewSearchLine( parent, 0, name )
+ : TDEListViewSearchLine( parent, 0, name )
{
}
@@ -58,9 +58,9 @@ void SearchLine::updateSearch( const TQString &s )
switch( listView()->selectionMode() )
{
- case KListView::NoSelection:
+ case TDEListView::NoSelection:
break;
- case KListView::Single:
+ case TDEListView::Single:
currentItem = listView()->selectedItem();
break;
default:
diff --git a/kopete/libkopete/ui/kopetestdaction.cpp b/kopete/libkopete/ui/kopetestdaction.cpp
index f69adcfc..5a589293 100644
--- a/kopete/libkopete/ui/kopetestdaction.cpp
+++ b/kopete/libkopete/ui/kopetestdaction.cpp
@@ -36,11 +36,11 @@
KSettings::Dialog *KopetePreferencesAction::s_settingsDialog = 0L;
-KopetePreferencesAction::KopetePreferencesAction( KActionCollection *parent, const char *name )
+KopetePreferencesAction::KopetePreferencesAction( TDEActionCollection *parent, const char *name )
#if KDE_IS_VERSION( 3, 3, 90 )
-: KAction( KStdGuiItem::configure(), 0, 0, 0, parent, name )
+: TDEAction( KStdGuiItem::configure(), 0, 0, 0, parent, name )
#else
-: KAction( KGuiItem( i18n( "&Configure Kopete..." ),
+: TDEAction( KGuiItem( i18n( "&Configure Kopete..." ),
TQString::fromLatin1( "configure" ) ), 0, 0, 0, parent, name )
#endif
{
@@ -63,64 +63,64 @@ void KopetePreferencesAction::slotShowPreferences()
KWin::activateWindow( s_settingsDialog->dialog()->winId() );
}
-KAction * KopeteStdAction::preferences( KActionCollection *parent, const char *name )
+TDEAction * KopeteStdAction::preferences( TDEActionCollection *parent, const char *name )
{
return new KopetePreferencesAction( parent, name );
}
-KAction * KopeteStdAction::chat( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::chat( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "Start &Chat..." ), TQString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "Start &Chat..." ), TQString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::sendMessage( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::sendMessage( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "&Send Single Message..." ), TQString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "&Send Single Message..." ), TQString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::contactInfo( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::contactInfo( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "User &Info" ), TQString::fromLatin1( "messagebox_info" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "User &Info" ), TQString::fromLatin1( "messagebox_info" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::sendFile( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::sendFile( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "Send &File..." ), TQString::fromLatin1( "attach" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "Send &File..." ), TQString::fromLatin1( "attach" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::viewHistory( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::viewHistory( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "View &History..." ), TQString::fromLatin1( "history" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "View &History..." ), TQString::fromLatin1( "history" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::addGroup( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::addGroup( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "&Create Group..." ), TQString::fromLatin1( "folder" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "&Create Group..." ), TQString::fromLatin1( "folder" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::changeMetaContact( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::changeMetaContact( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "Cha&nge Meta Contact..." ), TQString::fromLatin1( "move" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "Cha&nge Meta Contact..." ), TQString::fromLatin1( "move" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::deleteContact( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::deleteContact( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "&Delete Contact" ), TQString::fromLatin1( "delete_user" ), TQt::Key_Delete, recvr, slot, parent, name );
+ return new TDEAction( i18n( "&Delete Contact" ), TQString::fromLatin1( "delete_user" ), TQt::Key_Delete, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::changeAlias( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
+TDEAction * KopeteStdAction::changeAlias( const TQObject *recvr, const char *slot, TQObject *parent, const char *name )
{
- return new KAction( i18n( "Change A&lias..." ), TQString::fromLatin1( "signature" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "Change A&lias..." ), TQString::fromLatin1( "signature" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::blockContact( const TQObject *recvr, const char *slot, TQObject* parent, const char *name )
+TDEAction * KopeteStdAction::blockContact( const TQObject *recvr, const char *slot, TQObject* parent, const char *name )
{
- return new KAction( i18n( "&Block Contact" ), TQString::fromLatin1( "player_pause" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "&Block Contact" ), TQString::fromLatin1( "player_pause" ), 0, recvr, slot, parent, name );
}
-KAction * KopeteStdAction::unblockContact( const TQObject *recvr, const char *slot, TQObject* parent, const char *name )
+TDEAction * KopeteStdAction::unblockContact( const TQObject *recvr, const char *slot, TQObject* parent, const char *name )
{
- return new KAction( i18n( "Un&block Contact" ), TQString::fromLatin1( "player_play" ), 0, recvr, slot, parent, name );
+ return new TDEAction( i18n( "Un&block Contact" ), TQString::fromLatin1( "player_play" ), 0, recvr, slot, parent, name );
}
#include "kopetestdaction.moc"
diff --git a/kopete/libkopete/ui/kopetestdaction.h b/kopete/libkopete/ui/kopetestdaction.h
index 895ad180..376548b9 100644
--- a/kopete/libkopete/ui/kopetestdaction.h
+++ b/kopete/libkopete/ui/kopetestdaction.h
@@ -34,57 +34,57 @@ public:
/**
* Standard action to start a chat
*/
- static KAction *chat( const TQObject *recvr, const char *slot,
+ static TDEAction *chat( const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0 );
/**
* Standard action to send a single message
*/
- static KAction *sendMessage(const TQObject *recvr, const char *slot,
+ static TDEAction *sendMessage(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to open a user info dialog
*/
- static KAction *contactInfo(const TQObject *recvr, const char *slot,
+ static TDEAction *contactInfo(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to open a history dialog or something similar
*/
- static KAction *viewHistory(const TQObject *recvr, const char *slot,
+ static TDEAction *viewHistory(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to initiate sending a file to a contact
*/
- static KAction *sendFile(const TQObject *recvr, const char *slot,
+ static TDEAction *sendFile(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to change a contacts @ref Kopete::MetaContact
*/
- static KAction *changeMetaContact(const TQObject *recvr, const char *slot,
+ static TDEAction *changeMetaContact(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to add a group
*/
- static KAction *addGroup(const TQObject *recvr, const char *slot,
+ static TDEAction *addGroup(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to delete a contact
*/
- static KAction *deleteContact(const TQObject *recvr, const char *slot,
+ static TDEAction *deleteContact(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to change a contact alias/nickname in your contactlist
*/
- static KAction *changeAlias(const TQObject *recvr, const char *slot,
+ static TDEAction *changeAlias(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to block a contact
*/
- static KAction *blockContact(const TQObject *recvr, const char *slot,
+ static TDEAction *blockContact(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
* Standard action to unblock a contact
*/
- static KAction *unblockContact(const TQObject *recvr, const char *slot,
+ static TDEAction *unblockContact(const TQObject *recvr, const char *slot,
TQObject* parent, const char *name = 0);
/**
@@ -92,7 +92,7 @@ public:
*
* The object has no signal/slot, the prefs are automatically shown
*/
- static KAction *preferences(KActionCollection *parent, const char *name = 0);
+ static TDEAction *preferences(TDEActionCollection *parent, const char *name = 0);
};
@@ -101,13 +101,13 @@ namespace KSettings
class Dialog;
}
-class KOPETE_EXPORT KopetePreferencesAction : public KAction
+class KOPETE_EXPORT KopetePreferencesAction : public TDEAction
{
Q_OBJECT
public:
- KopetePreferencesAction( KActionCollection *parent, const char *name = 0 );
+ KopetePreferencesAction( TDEActionCollection *parent, const char *name = 0 );
~KopetePreferencesAction();
protected slots:
diff --git a/kopete/libkopete/ui/kopeteview.h b/kopete/libkopete/ui/kopeteview.h
index c54b1dba..b1daf472 100644
--- a/kopete/libkopete/ui/kopeteview.h
+++ b/kopete/libkopete/ui/kopeteview.h
@@ -136,7 +136,7 @@ class KOPETE_EXPORT KopeteView
* menus that can be extended
*
* @param target A target TQObject for the contextMenuEvent signal of the view
- * @param slot A slot that matches the signature ( TQString&, KPopupMenu *)
+ * @param slot A slot that matches the signature ( TQString&, TDEPopupMenu *)
*/
virtual void registerContextMenuHandler( TQObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
@@ -152,7 +152,7 @@ class KOPETE_EXPORT KopeteView
* to show tooltips
*
* @param target A target TQObject for the contextMenuEvent signal of the view
- * @param slot A slot that matches the signature ( TQString&, KPopupMenu *)
+ * @param slot A slot that matches the signature ( TQString&, TDEPopupMenu *)
*/
virtual void registerTooltipHandler( TQObject *target, const char*slot ){ Q_UNUSED(target); Q_UNUSED(slot); };
diff --git a/kopete/libkopete/ui/kopetelistviewsearchline.h b/kopete/libkopete/ui/kopetelistviewsearchline.h
index 55d3ce91..70b419d5 100644
--- a/kopete/libkopete/ui/kopetelistviewsearchline.h
+++ b/kopete/libkopete/ui/kopetelistviewsearchline.h
@@ -26,7 +26,7 @@ namespace ListView {
class ListView;
-class SearchLine : public KListViewSearchLine
+class SearchLine : public TDEListViewSearchLine
{
Q_OBJECT
@@ -41,7 +41,7 @@ public:
SearchLine( TQWidget *parent, ListView *listView = 0, const char *name = 0 );
/**
* Constructs a SearchLine without any ListView to filter. The
* KListView object has to be set later with setListView().
*/
SearchLine(TQWidget *parent, const char *name);
/**
@@ -41,7 +41,7 @@ public:
/**
* Constructs a SearchLine without any ListView to filter. The
- * KListView object has to be set later with setListView().
+ * TDEListView object has to be set later with setListView().
*/
SearchLine(TQWidget *parent, const char *name);